<?php

/**
 * @file
 *  Implementation of Feeds mapping API for numeric_interval.module.
 */

/**
 * Implements hook_feeds_node_processor_targets_alter().
 */
function numeric_interval_feeds_processor_targets_alter(&$targets, $entity_type, $bundle_name) {
  foreach (field_info_instances($entity_type, $bundle_name) as $name => $instance) {
    $info = field_info_field($name);
    if ($info['type'] == 'numeric_interval') {
      $targets[$name . ':val1'] = array(
        'name' => $instance['label'] . ': ' . t('Start'),
        'callback' => 'numeric_interval_set_target',
        'description' => t('The @label interval fields start value.', array('@label' => $instance['label'])),
        'real_target' => $info['field_name'],
      );
      $targets[$name . ':val2'] = array(
        'name' => $instance['label'] . ': ' . t('End'),
        'callback' => 'numeric_interval_set_target',
        'description' => t('The @label interval fields end value.', array('@label' => $instance['label'])),
        'real_target' => $info['field_name'],
      );
    }
  }
}

/**
 * Callback for hook_feeds_processor_targets_alter().
 *
 * @param $source
 *   Field mapper source settings.
 * @param $entity
 *   An entity object, for instance a node object.
 * @param $target
 *   A string identifying the target on the node.
 * @param $value
 *   The value to populate the target with.
 */
function numeric_interval_set_target($source, $entity, $target, $value) {
  if (empty($value)) {
    return;
  }

  // Handle non-multiple value fields.
  if (!is_array($value)) {
    $value = array($value);
  }

  // Determine the field we are matching against.
  list($field_name, $sub_field) = explode(':', $target, 2);

  $field = isset($entity->$field_name) ? $entity->$field_name : array();

  foreach ($value as $i => $v) {
    $field['und'][$i][$sub_field] = $v;
  }

  $entity->{$field_name} = $field;
}
